==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/pt.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Gerir Parâmetros Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Gerenciar Galeria");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Largura da imagem");
define('MANAGE_GALLERY_FULL_HEIGHT', "Imagem em tamanho real Altura");
define('MANAGE_GALLERY_THUMB_WIDTH', "Largura da imagem em miniatura");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Miniatura Altura");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Preserve Aspect Ratio Thumb");
define('MANAGE_GALLERY_SHOW_TITLES', "Mostrar títulos");
define('MANAGE_GALLERY_DISABLE_SORT', "Disable Sort");
define('MANAGE_GALLERY_DELETE_IMAGE', "excluir imagem");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Salve Ordem de Classificação");
define('MANAGE_GALLERY_PUBLISH_MSG', "Clique em &#39;Update&#39; para publicar <br /> suas imagens carregadas.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Todas as imagens foram redimensionadas e configurações foram salvas.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Houve um erro redimensionar as imagens ou salvar configurações.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Sua imagem (s) foi carregado.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Houve um erro ao enviar sua imagem (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "O arquivo que você está tentando carregar não é uma imagem.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "O arquivo que você está tentando carregar é muito grande.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "O título foi salvo.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Tem certeza de que quer apagar imagem");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "A imagem foi apagada.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Houve um erro ao excluir a imagem.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Salvando parâmetros e redimensionar imagens, por favor aguarde ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Carregar, aguarde por favor ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "A ordem de classificação não foi salvo. Você quer salvar a ordem de classificação?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "A ordem imagem tipo foi salvo.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Houve um erro ao salvar o tipo de imagem.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/pt.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Gerir Parâmetros Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Gerenciar Galeria");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Largura da imagem");
define('MANAGE_GALLERY_FULL_HEIGHT', "Imagem em tamanho real Altura");
define('MANAGE_GALLERY_THUMB_WIDTH', "Largura da imagem em miniatura");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Miniatura Altura");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Preserve Aspect Ratio Thumb");
define('MANAGE_GALLERY_SHOW_TITLES', "Mostrar títulos");
define('MANAGE_GALLERY_DISABLE_SORT', "Disable Sort");
define('MANAGE_GALLERY_DELETE_IMAGE', "excluir imagem");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Salve Ordem de Classificação");
define('MANAGE_GALLERY_PUBLISH_MSG', "Clique em &#39;Update&#39; para publicar <br /> suas imagens carregadas.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Todas as imagens foram redimensionadas e configurações foram salvas.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Houve um erro redimensionar as imagens ou salvar configurações.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Sua imagem (s) foi carregado.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Houve um erro ao enviar sua imagem (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "O arquivo que você está tentando carregar não é uma imagem.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "O arquivo que você está tentando carregar é muito grande.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "O título foi salvo.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Tem certeza de que quer apagar imagem");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "A imagem foi apagada.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Houve um erro ao excluir a imagem.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Salvando parâmetros e redimensionar imagens, por favor aguarde ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Carregar, aguarde por favor ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "A ordem de classificação não foi salvo. Você quer salvar a ordem de classificação?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "A ordem imagem tipo foi salvo.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Houve um erro ao salvar o tipo de imagem.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "O arquivo que você está tentando enviar é maior que as configurações do PHP &#39;upload_max_filesize&#39; ou &#39;post_max_size&#39;. Entre em contato com o administrador do sistema para aumentar esses limites.");
?>
